pub fn cmd_execstdin(opts: &ProcessOpts) -> Result<(), Error>Expand description
Execute a job using a job file piped in on stdin. This is just a very
thin wrapper around cmd_exec_generic.
pub fn cmd_execstdin(opts: &ProcessOpts) -> Result<(), Error>Execute a job using a job file piped in on stdin. This is just a very
thin wrapper around cmd_exec_generic.